@@ -29,6 +29,7 @@
 #include "gengetopt.h"
 
 extern int gengetopt_count_line;
+extern char * gengetopt_input_filename;
 
 static int gengetopt_package_given = 0;
 static int gengetopt_version_given = 0;
@@ -41,7 +42,7 @@ extern int yylex () ;
 #define check_result \
 	if (o) { switch (o) { case 1: yyerror ("not enough memory"); break; case 2: yyerror ("long option redefined"); break; case 3: yyerror ("short option redefined"); break; case 4: yyerror ("bug found!!"); break; } YYERROR; }
 
-#line 45 "parser.y"
+#line 46 "parser.y"
 typedef union {
 char * str;
 char chr;
@@ -113,8 +114,8 @@ static const short yyrhs[] = {    -1,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-    74,    75,    79,    82,    86,    87,    91,    95,    98,   101,
-   103,   107,   111,   114,   131,   132
+    75,    76,    80,    83,    87,    88,    92,    96,    99,   102,
+   104,   108,   112,   115,   134,   135
 };
 #endif
 
@@ -717,51 +718,51 @@ yyreduce:
   switch (yyn) {
 
 case 3:
-#line 79 "parser.y"
+#line 80 "parser.y"
 { yyval.str = yyvsp[0].str; ;
     break;}
 case 4:
-#line 82 "parser.y"
+#line 83 "parser.y"
 { yyval.str = yyvsp[0].str; ;
     break;}
 case 5:
-#line 86 "parser.y"
+#line 87 "parser.y"
 { yyval.bool = 1; ;
     break;}
 case 6:
-#line 87 "parser.y"
+#line 88 "parser.y"
 { yyval.bool = 0; ;
     break;}
 case 7:
-#line 91 "parser.y"
+#line 92 "parser.y"
 { if (gengetopt_package_given) { yyerror ("package redefined"); YYERROR; } else { gengetopt_package_given = 1; if (gengetopt_define_package (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 8:
-#line 95 "parser.y"
+#line 96 "parser.y"
 { if (gengetopt_version_given) { yyerror ("version redefined"); YYERROR; } else { gengetopt_version_given = 1; if (gengetopt_define_version (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 9:
-#line 98 "parser.y"
+#line 99 "parser.y"
 { if (gengetopt_purpose_given) { yyerror ("purpose redefined"); YYERROR; } else { gengetopt_purpose_given = 1; if (gengetopt_define_purpose (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 10:
-#line 101 "parser.y"
+#line 102 "parser.y"
 { if (gengetopt_purpose_given) { yyerror ("purpose redefined"); YYERROR; } else { gengetopt_purpose_given = 1; if (gengetopt_define_purpose (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 11:
-#line 103 "parser.y"
+#line 104 "parser.y"
 { int o = gengetopt_add_option (yyvsp[-3].str, yyvsp[-2].chr, yyvsp[-1].str, ARG_NO, 0, 0, 0); check_result; ;
     break;}
 case 12:
-#line 107 "parser.y"
+#line 108 "parser.y"
 { int o = gengetopt_add_option (yyvsp[-4].str, yyvsp[-3].chr, yyvsp[-2].str, ARG_FLAG, yyvsp[0].bool, 0, 0); check_result; ;
     break;}
 case 13:
-#line 111 "parser.y"
+#line 112 "parser.y"
 { int o = gengetopt_add_option (yyvsp[-4].str, yyvsp[-3].chr, yyvsp[-2].str, yyvsp[-1].argtype, 0, yyvsp[0].bool, 0); check_result; ;
     break;}
 case 14:
-#line 115 "parser.y"
+#line 116 "parser.y"
 { 
   int o = gengetopt_add_option (yyvsp[-5].str, yyvsp[-4].chr, yyvsp[-3].str, yyvsp[-2].argtype, 0, yyvsp[0].bool, yyvsp[-1].str); 
   check_result; 
@@ -770,19 +771,21 @@ case 14:
     {
       fprintf 
         (stderr, 
-         "gengetopt: %d: Warning: default values may not work correctly with "
-         "type %s\n", gengetopt_count_line, arg_names [yyvsp[-2].argtype]);
+         "%s:%d: Warning: default values may not work correctly with "
+         "type %s\n",
+         (gengetopt_input_filename ? gengetopt_input_filename : "gengetopt"),
+         gengetopt_count_line, arg_names [yyvsp[-2].argtype]);
       fprintf
         (stderr, "This problem will be fixed in future releases.\n");
     }
 ;
     break;}
 case 15:
-#line 131 "parser.y"
+#line 134 "parser.y"
 { yyval.str = 0; ;
     break;}
 case 16:
-#line 132 "parser.y"
+#line 135 "parser.y"
 { yyval.str = yyvsp[0].str; ;
     break;}
 }
@@ -1007,7 +1010,7 @@ yyerrhandle:
     }
   return 1;
 }
-#line 135 "parser.y"
+#line 138 "parser.y"
 
 
 
